Author: Carlos Lopez <[email protected]>
Date:   Thu Jul 28 09:41:47 2011 +0200

Fix wrong value insertion in the DIList

---

 synfig-core/src/synfig/valuenode_dilist.cpp |    5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)

diff --git a/synfig-core/src/synfig/valuenode_dilist.cpp 
b/synfig-core/src/synfig/valuenode_dilist.cpp
index cf76a76..aff992c 100644
--- a/synfig-core/src/synfig/valuenode_dilist.cpp
+++ b/synfig-core/src/synfig/valuenode_dilist.cpp
@@ -106,10 +106,11 @@ ValueNode_DIList::ListEntry
 ValueNode_DIList::create_list_entry(int index, Time time, Real /*origin*/)
 {
        ValueNode_DIList::ListEntry ret;
+       synfig::DashItem inserted;
        int new_index(find_prev_valid_entry(index, time));
        ret.index=new_index;
        ret.set_parent_value_node(this);
-       ret.value_node=ValueNode_Composite::create(ret);
+       ret.value_node=ValueNode_Composite::create(inserted);
        ret.value_node->set_parent_canvas(get_parent_canvas());
        return ret;
 }
@@ -130,7 +131,7 @@ ValueNode_DIList::operator()(Time t)const
        // go through all the list's entries
        for(iter=list.begin();iter!=list.end();++iter)
        {
                // how 'on' is this widthpoint?
                float amount(iter->amount_at_time(t,&rising));
                assert(amount>=0.0f);
                assert(amount<=1.0f);


------------------------------------------------------------------------------
@@ -130,7 +131,7 @@ ValueNode_DIList::operator()(Time t)const
        for(iter=list.begin();iter!=list.end();++iter)
        {
-               // how 'on' is this widthpoint?
+               // how 'on' is this dashitem?
                float amount(iter->amount_at_time(t,&rising));
                assert(amount>=0.0f);
Got Input?   Slashdot Needs You.
Take our quick survey online.  Come on, we don't ask for help often.
Plus, you'll get a chance to win $100 to spend on ThinkGeek.
http://p.sf.net/sfu/slashdot-survey
_______________________________________________
Synfig-devl mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/synfig-devl

Reply via email to